# Monthly Scripts for State of the Climate Tropical Report and Synoptic Discussion
# Obtaining package
This package relies on some custom python package that are bundled as submodules in this repo.
To clone the package and initialize the submodules in one command, run the following:

    git clone --recurse-submodules /url/to/repo

If you have already cloned the repo and need to initialize the submodules, use the following:

    git submodule update --init --recursive



## Prerequisite
```bash
conda activate base
conda create --name monthly_monitor --file requirements.txt
```

## Tropical Cyclone Report
### Kick off jobs on shiva to create report:
```bash
python bsub_ibtracs.py
```
* Downloads the latest IBTrACS data
* Merges it with the last version created before WMO Best Tracks overwrote preliminary tracks from JTWC
* ```ibtracs_monthly_monitor.py```
  * Creates the tropical-cyclones-YYYYMM.json file
    * Key statistics (counts, ACE) for each basin
    * List of storms for each basin
  * Draws a track map for each storm
* ibtracs_basin_maps.py
  * Draws track maps for each basin, both for the current month and year to date
* All output will go to: ```fig_dir = /glfs0/anon-ftp/pub/carl/monitor/tropical-cyclones/``` as defined in ```bsub_ibtracs.py```.

### Once the jobs complete, go to climon-prod from your NOAA PC and run
```bash
bash download_tropical.sh
```
* Creates a new directory for report assets: ```/mondata/preview/sotc/tropical-cyclones/$year/$month```
* Removes any png or json files currently in that directory
* Downloads all the files from ftp://anonymous@filsrv.cicsnc.org/carl/monitor/tropical-cyclones/ and sets the right permissions.
* If a report html for this month does not exist, it copies a blank starter report

### Edit the new report:
* ```/mondata/preview/sotc/tropical-cyclones/reports/tropical-cyclones-YYYYMM.html```
* Preview progress and tables at https://www.test.ncei.noaa.gov/access/monitoring/monthly-report/tropical-cyclones/
* Fill in global stats in the first paragraph.
* Subsequent paragraphs go basin-by-basin discussing monthly activity and noteworthy storms
* For storms, link to their track map from the report
* Find an eye-catching satellite image for a significant storm and add it using the floatImage block at the top of the html--preferably from a NOAA.gov, NASA.gov, or cooperative institute source
* Check links, then email the test link to the Global Report lead author and the monitoring section chief

### Key resources:
* [Most recent report](https://www.ncei.noaa.gov/access/monitoring/monthly-report/tropical-cyclones/)
* [Current preliminary report](https://www.test.ncei.noaa.gov/access/monitoring/monthly-report/tropical-cyclones/)
* [NHC Monthly Tropical Cyclone Summary](https://www.nhc.noaa.gov/archive/tws/)
* [CSU real-time global statistics](https://tropical.atmos.colostate.edu/Realtime/)
* [CIRA page with satellite and track information](https://rammb-data.cira.colostate.edu/tc_realtime/)
* [IBTrACS website](https://ncics.org/ibtracs/)
* [Aon catastrophe reports](https://www.aon.com/reinsurance/catastropheinsight/default)--must sign up for weekly email reports. Great resource for damage information
* [Wikipedia pages for each basin/season/storm](https://en.wikipedia.org/wiki/2023_Atlantic_hurricane_season)
* [CIMSS Satellite Blog for tropical cyclone images](https://cimss.ssec.wisc.edu/satellite-blog/archives/category/tropical-cyclones)
* [NASA Earth Observatory storm images](https://earthobservatory.nasa.gov/topic/severe-storms)
* [rURL chrome extension](https://chromewebstore.google.com/detail/rurl/lgkbcnabknojommeiggfgjhjdljgdkbb?) -- copies the relative path for use in the html files


## Synoptic Discussion
### Make initial maps
```bash
python bsub_init_maps.py
```
* Downloads the latest nClimGrid-Daily and z500 data
* Kicks off jobs to create initial daily/weekly maps of temperature, precipitation, and z500.
* Output will go to subdirectories of ```synoptic/``` within the current directory.
* Look at them, particularly the weekly maps, to decide on 3-5 periods of at least 5 days.

### Make final plots
Put the first days of each period into ```bsub_final_maps.py```:
```python
first_days = np.array([1, 8, 25 ])
```
Then run
```bash
python bsub_final_maps.py
```
* Downloads the latest nClimGrid-Daily and z500 data
* Kicks off cluster jobs to draw all maps
* Additional jobs creates teleconnections time series and RMM MJO index plots
* All output will go to ```fig_dir = '/glfs0/anon-ftp/pub/carl/monitor/synoptic'``` from ```bsub_final_maps.py```

### Once the jobs complete, go to climon-prod from your NOAA PC and run
```bash
bash download_synoptic.sh
```
* Creates a new directory for report assets: ```/mondata/preview/sotc/synoptic/$year/$month```
* Removes any png files currently in that directory
* Puts 500-hPa height maps in ```/mondata/preview/sotc/national/hgtanomaly-usa/``` and ``` /mondata/preview/sotc/global/hgtanomaly-global/``` for other reports
* Downloads all the files from ftp://anonymous@filsrv.cicsnc.org/carl/monitor/tropical-cyclones/ and sets the right permissions.
* If a report html for this month does not exist, it copies last month's report and changes the month names/numbers throughout.

### Edit the new report:
* ```/mondata/preview/sotc/tropical-cyclones/reports/synoptic-YYYYMM.html```
* Preview progress at https://www.test.ncei.noaa.gov/access/monitoring/monthly-report/synoptic/
* For each submonthly period, replace both the text date (e.g., "1-7") and the url date (e.g., "0801-0807") from last month's periods to the current ones using
```
:%s/Search-String/Replace-String/g
```
* If needed, comment/uncomment out additional periods
* Delete all the key drivers from the top of the report
* Go through each teleconnection (Atmospheric Drivers Section):
  * Update the status. 
    * On shiva, ```monthly_monitor/log/telecon_timeseries.log``` lists the most extreme percentiles for most teleconnections. 
    * It lists them by value, rank, and percentile. 
    * Percentile >60 is positive/negative, and >90 is strong.
  * Update the teleconnections by comparing the composite maps (linked in the bullet) with the maps for this month's report.
    * Add the teleconnection to the Key Drivers lists at the top of the report as appropriate
    * Tip: I usually have two browser windows open, both pointing to the preview report. In one window, I look at the submonthly evolution, and I use the other to look at the teleconnection indices and composites
    * Some teleconnections only affect precipitation during particular seasons, and these are noted in the comments.
    * Commented out versions of all the teleconnections are available at the top of the Key driver section. Copy and paste from here to include links for descriptions
    * After the first time it appears in Key Drivers, I usually just use the abbreviation (e.g., "Positive AO") instead of copying the link again.
* Go through each period in the Submonthly Evolution and write a paragraph describing:
  * General circulation pattern, noting any dominant teleconnections
  * The related temperature/precipitation patterns
  * Any significant weather events, particularly those noted in the National Report's Significant Events or Highlights.
* Write a similar paragraph for the monthly mean (Summary). Note if any periods or events drove in the monthly mean.
* Check links, then email the test link to all the authors of the National Report (Rocky, Karin, Richard, and Russ)


### Key resources:
* [Most recent report](https://www.ncei.noaa.gov/access/monitoring/monthly-report/synoptic/)
* [ENSO Indices](https://www.cpc.ncep.noaa.gov/data/indices/)
  * [Weekly Nino 3.4](https://www.cpc.ncep.noaa.gov/data/indices/wksst9120.for)
  * [SOI](https://www.cpc.ncep.noaa.gov/data/indices/soi)
* [CPC ENSO Discussion](https://www.cpc.ncep.noaa.gov/products/analysis_monitoring/enso_advisory/ensodisc.shtml) -- updated on the second Thursday
* [Archived Synoptic GFS Maps](https://www.atmos.albany.edu/student/abentley/realtime/archive.php) -- includes standardized anomalies
* [Archived weather maps](ftp://anonymous@filsrv.cicsnc.org/carl/monitor/sfcplot) from [WPC](https://www.wpc.ncep.noaa.gov/NationalForecastChart/staticmaps/)
* [rURL chrome extension](https://chromewebstore.google.com/detail/rurl/lgkbcnabknojommeiggfgjhjdljgdkbb?) -- copies the relative path for use in the html files
