""" Download monthly and seasonal maps"""

__author__ = "Carl Schreck"
__email__ = "carl_schreck@ncsu.edu"
__copyright__ = "Copyright 2022, North Carolina State University"
__license__ = "BSD-3.0"

import logging
from datetime import datetime
import os
import cjs.fileio

# Set up logging
logging.basicConfig(
    format='%(asctime)s %(levelname)s %(name)-15s %(message)s',
    level=logging.INFO,
    datefmt='%H:%M:%S')
logger = logging.getLogger(__name__)


def download_maps(period='month', year=2022, month=12):
    local_path = f'synoptic/annual/{period}/'
    os.makedirs(local_path, exist_ok=True)
    if period == 'month':
        date_string = f'{year}{month:02}'
    elif period == 'season':
        date_string = f'{year}{month-2:02}-{year}{month:02}'
    server_path = 'https://www.ncei.noaa.gov/monitoring-content/sotc/national/'
    cjs.fileio.download_file(
        remote_path=(f'{server_path}/grid-temp/'
                     f'tave-anom-{date_string}.png'
                     ),
        local_path=local_path)
    cjs.fileio.download_file(
        remote_path=(f'{server_path}/grid-prcp/'
                     f'prcp-pon-{date_string}.png'
                     ),
        local_path=local_path)
    cjs.fileio.download_file(
        remote_path=(f'{server_path}/grid-ranks-prcp/'
                     f'grid-ranks-prcp-{date_string}.png'
                     ),
        local_path=local_path)
    cjs.fileio.download_file(
        remote_path=(f'{server_path}/grid-ranks-temp/'
                     f'grid-ranks-tavg-{date_string}.png'
                     ),
        local_path=local_path)


def main():
    logger.info('Here we go!')
    year = datetime.today().year-1
    for month in range(1,13):
        logger.info(month)
        download_maps(period='month', year=year, month=month)
        if month > 2:
            download_maps(period='season', year=year, month=month)
    logger.info('Thank you, come again.')

if __name__ == "__main__":
    main()