""" Kick off the cluster jobs to make monitoring maps for custom periods in
month."""

__author__ = "Carl Schreck"
__email__ = "carl_schreck@ncsu.edu"
__copyright__ = "Copyright 2020, North Carolina State University"
__license__ = "BSD-3.0"

import numpy as np
import os
import argparse
import subprocess
from datetime import datetime
import glob
import calendar
import cjs.text
import cjs.fileio

# These are some parameters that could be useful to have up top
parser = argparse.ArgumentParser()
year = datetime.today().year-1
dpi = 150
clobber = True

var_name = 'z500'

cjs.text.tstamp('Here we go!')
# fig_dir = f'synoptic/annual/'
fig_dir = f'/glfs0/anon-ftp/pub/carl/monitor/synoptic-{year}13'
os.makedirs(fig_dir, exist_ok=True)
# old_files = glob.glob(f'{fig_dir}/*')
# for file in old_files:
#     os.remove(file)

file_name = f'hgt.{year}.nc'
in_path = f'{os.environ["DATA_DIR"]}/ncep1/esrl/daily/{file_name}'
ftp_path = (
    f'ftp://ftp.cdc.noaa.gov/Datasets/ncep.reanalysis.dailyavgs/'
    f'pressure/{file_name}')
download_err = cjs.fileio.download_file(ftp_path, in_path, clobber=clobber)

first_months = [1, 4, 6, 8, 10]
# first_months = np.arange(1, 11)

regions = ['namer', 'nhem']

py_dir = os.getcwd()
# py_script = f'{var_name}_map.py'
py_script = 'z500_mean_anom'
log_dir = f'{py_dir}/log'
os.makedirs(log_dir, exist_ok=True)

for first_month in first_months:
    last_month = first_month + 2
    days_in_month = calendar.monthrange(year, last_month)[1]
    first_day = 1
    last_day = days_in_month

    for region in regions:
        job_name = f'{var_name}_{first_month}_{last_month}_{region}'
        log_file = f'{log_dir}/{job_name}.log'
        err_file = f'{log_dir}/{job_name}.err'
        try:
            os.remove(log_file)
        except OSError:
            pass
        try:
            os.remove(err_file)
        except OSError:
            pass

        py_option = f'--first_date {year}-{first_month:02}-{first_day:02} ' \
                    f'--last_date {year}-{last_month:02}-{last_day:02} ' \
                    f'--region {region} ' \
                    f'--dpi {dpi} --fig_dir {fig_dir}'

        command = f'bsub -J {job_name} -o {log_file} -e {err_file} ' \
                  f'-q allnodes -sp 75 /home/carl/template/run_py.sh ' \
                  f'{py_dir} {py_script} "{py_option}"'
        subprocess.Popen(command, shell=True)




cjs.text.tstamp('Thank you, come again.')

