""" Kick off the cluster jobs to make monitoring maps for each day of the
month."""

__author__ = "Carl Schreck"
__email__ = "carl_schreck@ncsu.edu"
__copyright__ = "Copyright 2020, North Carolina State University"
__license__ = "BSD-3.0"

import numpy as np
import os
import argparse
import subprocess
from datetime import datetime
import glob
import calendar
import cjs.text

# These are some parameters that could be useful to have up top
parser = argparse.ArgumentParser()
parser.add_argument('--year', default=(datetime.today().year))
parser.add_argument('--month', default=(datetime.today().month - 1))
parser.add_argument('--dpi', default=200)
args = parser.parse_args()
year = int(args.year)
month = int(args.month)
dpi = int(args.dpi)
if month < 1:
    month += 12
    year -= 1

start_day = 1
days_in_month = calendar.monthrange(year, month)[1]
clobber = False

py_script = 'tavg_total_anom'
delta_day = 1

cjs.text.tstamp('Here we go!')
fig_dir = f'figures/{py_script}-{delta_day}'
os.makedirs(fig_dir, exist_ok=True)
old_files = glob.glob(f'{fig_dir}/*')
for file in old_files:
    os.remove(file)

first_days = np.arange(start_day, days_in_month - delta_day + 2, 1)
last_days = np.arange(start_day + delta_day - 1, days_in_month + 1, 1)
for first_day, last_day in zip(first_days, last_days):

    py_dir = os.getcwd()
    log_dir = f'{py_dir}/log'
    os.makedirs(log_dir, exist_ok=True)
    job_name = f'{py_script}_{first_day}_{last_day}'
    log_file = f'{log_dir}/{job_name}.log'
    err_file = f'{log_dir}/{job_name}.err'
    try:
        os.remove(log_file)
    except OSError:
        pass
    try:
        os.remove(err_file)
    except OSError:
        pass

    py_option = f'--year {year} --month {month} ' \
                f'--first_day {first_day} --last_day {last_day} ' \
                f'--dpi {dpi} --fig_dir {fig_dir}'

    command = f'bsub -J {job_name} -o {log_file} -e {err_file} ' \
              f'-q allnodes -sp 75 /home/carl/template/run_py.sh ' \
              f'{py_dir} {py_script} "{py_option}"'
    subprocess.Popen(command, shell=True)


cjs.text.tstamp('Thank you, come again.')

