""" Kick off the cluster jobs to make monitoring maps for custom periods in
month."""

__author__ = "Carl Schreck"
__email__ = "carl_schreck@ncsu.edu"
__copyright__ = "Copyright 2020, North Carolina State University"
__license__ = "BSD-3.0"

import os
import subprocess
import glob
import logging
from cjs import ibtracs

# Set up logging
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)

logger.info('Here we go!')
out_dir = f'/glfs0/anon-ftp/pub/carl/monitor/tropical-cyclones/'
os.makedirs(out_dir, exist_ok=True)
old_files = glob.glob(f'{out_dir}/*')
for file in old_files:
    os.remove(file)
py_dir = os.getcwd()
log_dir = f'{py_dir}/log'
os.makedirs(log_dir, exist_ok=True)
log_files = glob.glob(f'{log_dir}/ibtracs*')
for file in log_files:
    os.remove(file)

for epoch in ['last3years', 'ALL']:
    logger.info(f'downloading ibtracs {epoch}')
    ibt = ibtracs.Ibtracs(epoch, download_data=True)

script_names = ['ibtracs_monthly_monitor',
                'ibtracs_basin_maps']
for script_name in script_names:
    logger.info(script_name)

    job_name = script_name
    py_option = (f'--out_dir {out_dir}')

    log_file = f'{log_dir}/{job_name}.log'
    err_file = f'{log_dir}/{job_name}.err'
    command = (f'bsub -J {job_name} -o {log_file} -e {err_file} '
               f'-q allnodes -sp 75 {py_dir}/run_py.sh '
               f'{py_dir} {script_name} "{py_option}"')
    logger.info(command)
    subprocess.run(command, shell=True)


logger.info('Thank you, come again.')

