""" Download nclimgrid-daily files."""

__author__ = "Carl Schreck"
__email__ = "cjschrec@ncsu.edu"
__copyright__ = "Copyright 2022, North Carolina State University"
__license__ = "BSD-3.0"

import cjs.fileio
import os
import logging
import pandas as pd

# Set up logging
logger = logging.getLogger(__name__)

def download_nclimgrid(year, month, file_type='scaled', clobber=False,
                       out_dir=None):
    if out_dir == None:
        out_dir = f'{os.environ["DATA_DIR"]}/nclimgrid/v1-0-0/grids/{year}'
    os.makedirs(out_dir, exist_ok=True)
    ftp_path = (f'ftp://ftp.ncdc.noaa.gov/pub/data/daily-grids/v1-0-0/grids'
                f'/{year}')
    web_path = (f'https://www.ncei.noaa.gov/pub/data/daily-grids/v1-0-0/grids'
                f'/{year}')
    file_name = f'ncdd-{year}{month:02}-grd-{file_type}.nc'
    download_err = cjs.fileio.download_file(f'{ftp_path}/{file_name}',
                                            f'{out_dir}/{file_name}',
                                            clobber=clobber, quiet=True)
    if download_err:
        file_type = 'prelim'
        file_name = f'ncdd-{year}{month:02}-grd-{file_type}.nc'
        download_err = cjs.fileio.download_file(f'{ftp_path}/{file_name}',
                                                f'{out_dir}/{file_name}',
                                                clobber=clobber, quiet=True)
    out_path = f'{out_dir}/{file_name}'
    return out_path


def download_nclimgrid_daterange(first_date, last_date, clobber=False,
                                 file_type='scaled'):
    out_paths = []
    for dt in pd.date_range(first_date.strftime('%Y-%m'),
                            last_date.strftime('%Y-%m'), freq='MS'):
        logger.info(f'Downloading {str(dt.date)}')
        out_path = download_nclimgrid(dt.year, dt.month, clobber=clobber,
                                      file_type=file_type)
        out_paths.append(out_path)
    return out_paths
