""" For a given month and basin, rank the strongest storms. """

__author__ = "Carl Schreck"
__email__ = "carl_schreck@ncsu.edu"
__copyright__ = "Copyright 2021, North Carolina State University"
__license__ = "BSD-3.0"

import numpy as np
from cjs import ibtracs

print('Here we go!')
# These are some parameters that could be useful to have up top
months = np.arange(1, 6)
basin = 'GL'

ibt = ibtracs.Ibtracs('ALL', download_data=False)

fix_months = ibt.ds['time.month']
is_in_months = (False & fix_months.astype('bool'))
for month in months:
    is_in_months += (fix_months == month)

is_in_basin = ibt.check_basin(target_basin=basin)

good_wind = ibt.ds['usa_wind'].where(is_in_months & is_in_basin)
lmi = np.amax(good_wind, axis=1)
lmi[lmi.isnull()] = 0

sort_ind = np.argsort(lmi)[:10:-1]

df = ibt.ds['sid'][sort_ind].to_dataframe()
df['name'] = ibt.ds['name'][sort_ind]
df['season'] = ibt.ds['season'][sort_ind]
df['month'] = ibt.ds['time.month'][sort_ind,0]
df['basin'] = ibt.ds['basin'][sort_ind,0]
df['lmi'] = lmi[sort_ind]

print(df[:10])
print('Thank you, come again.')

