import matplotlib.patches as mpatches
import numpy as np
import pandas as pd

def rmm_draw(ax, rmm_pc, first_date, last_date, mjo_day_stride=5,
             color_ind=0):
    colors = np.array(['tab:red', 'tab:blue', 'tab:purple', 'tab:orange',
                       'tab:pink', 'tab:cyan', 'tab:olive', 'tab:brown'])

    x_data =  rmm_pc[0][first_date:last_date].values
    y_data =  rmm_pc[1][first_date:last_date].values

    time = pd.date_range(start=first_date, end=last_date)
    months = time.strftime("%Y-%m")
    days = time.day

    start_ind = 0
    while start_ind < len(months) - 1:
        curr_month = months[start_ind + 1]
        end_ind = 2 + max(index for index, value in enumerate(months) 
                          if value == curr_month)

        ax.set_autoscale_on(False)
        ax.plot(x_data[start_ind:end_ind],
                y_data[start_ind:end_ind], color=colors[color_ind],
                marker='.', markerfacecolor='k', markeredgecolor='none')


        mid_month_ind = [index for index, value in enumerate(days)
                         if value == 15 and months[index] == curr_month]

        if len(mid_month_ind) > 0:
            xy_mid = change_length(x_data[mid_month_ind[0]],
                                   y_data[mid_month_ind[0]], 0.7)

            ax.text(xy_mid[0], xy_mid[1],
                    time[mid_month_ind[0]].strftime('%b'),
                    color=colors[color_ind], ha='center', va='center')
        # Add day labels every 5 days
        for i in range(start_ind, end_ind-1):
            if (days[i] % mjo_day_stride == 0
                and mjo_day_stride > 0):
                xy_day = change_length(x_data[i], y_data[i], 0.15)

                ax.text(xy_day[0], xy_day[1], str(days[i]), fontsize=6,
                        ha='center', va='center', color=colors[color_ind])

        if color_ind < len(colors) - 1:
            color_ind += 1
        else:
            color_ind = 0

        start_ind = end_ind - 1

    return color_ind - 1


def change_length(in_x, in_y, delta):
    length = np.sqrt(in_x ** 2 + in_y ** 2)
    ratio = (length + delta) / length
    out_x = in_x * ratio
    out_y = in_y * ratio
    return out_x, out_y

