import numpy as np
import math

def rmm_phase_background(ax, axis_extent=4, radius=1):

    nPhase = 8

    radian = 4. * math.atan(1.0) / 180.
    n_circle = 361
    x_circle = radius * np.cos(np.linspace(0, 360, n_circle) * radian)
    y_circle = radius * np.sin(np.linspace(0, 360, n_circle) * radian)

    ax.plot(x_circle, y_circle, color='black', lw=0.5)
    ax.set_aspect('equal')

    r45  = radius * math.cos(45.0 * radian)
    r00  = radius
    e00  = axis_extent

    phase_line = np.array([
        [r00, e00, 0, 0], 
        [r45, e00, r45, e00], 
        [0, 0, r00, e00],
        [-r45, -e00, r45, e00],
        [-r00, -e00, 0, 0],
        [-r45, -e00, -r45, -e00],
        [0, 0, -r00, -e00],
        [r45, e00, -r45, -e00]
    ])

    edge = 0.75 * axis_extent
    e22  = 0.75 * axis_extent * math.cos(22.5 * radian)
    e67  = 0.75 * axis_extent * math.cos(67.5 * radian)

    phase_label = np.arange(1, nPhase + 1)
    phase_label_xy = np.array([
        [-e22, -e67],
        [-e67, -e22],
        [e67, -e22],
        [e22, -e67],
        [e22, e67],
        [e67, e22],
        [-e67, e22],
        [-e22, e67]
    ])

    for i in range(nPhase):
        ax.plot(phase_line[i, [0, 1]], phase_line[i, [2, 3]], color='black', lw=0.5)
        ax.text(phase_label_xy[i, 0], phase_label_xy[i, 1],
                 str(phase_label[i]), ha='center', va='center')

    edge = 0.9 * axis_extent
    ax.text(edge, 0, "Maritime Continent", rotation=-90, ha='center',
             va='center',
             bbox=dict(facecolor='white', alpha=1, edgecolor='none'))
    ax.text(0, -edge, "Indian Ocean", ha='center', va='center',
             bbox=dict(facecolor='white', alpha=1, edgecolor='none'))
    ax.text(0, edge, "Western Pacific", ha='center', va='center',
             bbox=dict(facecolor='white', alpha=1, edgecolor='none'))
    ax.text(-edge, 0, "West. Hem. and Africa", rotation=90, ha='center',
             va='center',
             bbox=dict(facecolor='white', alpha=1, edgecolor='none'))

    ax.set_xlim(-axis_extent, axis_extent)
    ax.set_ylim(-axis_extent, axis_extent)

